#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 neat-interpolation
version:              0.5.1.4
visibility:           public
id:                   neat-interpolation-0.5.1.4-1yE1Nrep2l86AVrnFc3EHs
key:                  neat-interpolation-0.5.1.4-1yE1Nrep2l86AVrnFc3EHs
license:              MIT
copyright:            (c) 2013, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/neat-interpolation
synopsis:
    Quasiquoter for neat and simple multiline text interpolation

description:
    Quasiquoter for producing Text values with support for
    a simple interpolation of input values.
    It removes the excessive indentation from the input and
    accurately manages the indentation of all lines of the interpolated variables.

category:             String, QuasiQuotes
abi:                  0bdf3470f5578f211e3fcb474b2d128f
exposed:              True
exposed-modules:      NeatInterpolation
hidden-modules:
    NeatInterpolation.Parsing NeatInterpolation.Prelude
    NeatInterpolation.String

import-dirs:          /usr/lib/ghc-9.6.6/site-local/neat-interpolation-0.5.1.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/neat-interpolation-0.5.1.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/neat-interpolation-0.5.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-neat-interpolation
hs-libraries:         HSneat-interpolation-0.5.1.4-1yE1Nrep2l86AVrnFc3EHs
depends:
    base-4.18.2.1 megaparsec-9.7.0-FZeM2D0SwgQIqL3zAXHxUp
    template-haskell-2.20.0.0 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-neat-interpolation/html/neat-interpolation.haddock

haddock-html:         /usr/share/doc/haskell-neat-interpolation/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

